@@ -199,7 +199,6 @@ class Client(Methods):
         name: str,
         api_id: Union[int, str] = None,
         api_hash: str = None,
-        end_client: Union[int, str] = None,
         app_version: str = APP_VERSION,
         device_model: str = DEVICE_MODEL,
         system_version: str = SYSTEM_VERSION,
@@ -227,7 +226,6 @@ class Client(Methods):
         self.name = name
         self.api_id = int(api_id) if api_id else None
         self.api_hash = api_hash
-        self.end_client = int(end_client) if end_client else None
         self.app_version = app_version
         self.device_model = device_model
         self.system_version = system_version
@@ -303,6 +301,7 @@ class Client(Methods):
         except ConnectionError:
             pass
 
+    '''
     async def endclient(
         self
     ):
@@ -320,6 +319,7 @@ class Client(Methods):
                     await self.stop()
             else:
                 pass
+    '''
 
     async def listen(self, chat_id, filters=None, timeout=None):
         if type(chat_id) != int:
